@@ -91,12 +91,13 @@ public class ContentMenuController {
 	  * Enables/disables the menu items, according to which entry is selected.
 	  * It assumes that an object is selected in the tree.
 	  */
-	public void updateMenuState() {		
+	public void updateMenuState() {
 		boolean isRootSelected = _contentPage.isRootSelected();
 		boolean isSelectedNodeRemote = _contentPage.isSelectedNodeRemote();
 		boolean isSuffixSelected = _contentPage.isSelectedNodeSuffix();
-		boolean isClipboardEmpty = _contentPage.isClipboardEmpty();		
-		Integer selectionActivationState = new Integer(AccountInactivation.CANNOT_BE_ACTIVATED_INACTIVATED);		
+		boolean isClipboardEmpty = _contentPage.isClipboardEmpty();
+		boolean isDnInClipboardEmpty = _contentPage.isDnInClipboardEmpty(); // used by move
+		Integer selectionActivationState = new Integer(AccountInactivation.CANNOT_BE_ACTIVATED_INACTIVATED);
 		Integer selectionVlvState = new Integer(CreateVLVIndex.CAN_NOT_HAVE_INDEX);
 		Integer selectionPWPState = new Integer(PasswordPolicyPanel.NO_PWP);
 
@@ -110,9 +111,10 @@ public class ContentMenuController {
 		updateAciMenuItems(isRootSelected);
 		updateRoleMenuItems(isRootSelected);
 		updateReferralMenuItems(isRootSelected);
-		updateCutCopyPasteMenuItems(isRootSelected,
+		updateMoveCopyPasteMenuItems(isRootSelected,
 									isSuffixSelected,
-									isClipboardEmpty);
+									isClipboardEmpty,
+									isDnInClipboardEmpty);
 		updateSearchMenuItems(isRootSelected);
 		updateActivateInactivateMenuItems(selectionActivationState, isSelectedNodeRemote);
 		updateVLVMenuItems(selectionVlvState, isSelectedNodeRemote);
@@ -232,10 +234,10 @@ public class ContentMenuController {
 								  _resource.getString("menu", "inactivate-description"),
 								  _listener),
 				new MenuItemSeparator(),
-				new MenuItemText( CUT,
-								  _resource.getString("menu", "EditCut"),
+				new MenuItemText( MOVE,
+								  _resource.getString("menu", "EditMove"),
 								  _resource.getString("menu",
-													  "EditCut-description"),
+													  "EditMove"),
 								  _listener),
 				new MenuItemText( COPY,
 								  _resource.getString("menu", "EditCopy"),
@@ -247,6 +249,11 @@ public class ContentMenuController {
 								  _resource.getString("menu",
 													  "EditPaste-description"),
 								  _listener),
+				new MenuItemText( MOVEPASTE,
+								  _resource.getString("menu", "EditMovePaste"),
+								  _resource.getString("menu",
+													  "EditMovePaste-description"),
+								  _listener),
 				new MenuItemText( DELETE,
 								  _resource.getString("menu", "EditDelete"),
 								  _resource.getString("menu",
@@ -257,8 +264,8 @@ public class ContentMenuController {
 								  _resource.getString("menu", "refresh"),
 									  _resource.getString("menu",
 														  "refresh-description"),
-								  _listener),									
-				};						
+								  _listener),
+				};
 		addShortCuts(_contextMenuItems);
 		setActionCommand(_contextMenuItems);
 	}
@@ -453,10 +460,10 @@ public class ContentMenuController {
 	private void createEditMenuItems() {
 		_editMenuItems = new IMenuItem[] {
 			new MenuItemSeparator(),
-				new MenuItemText( CUT,
-								  _resource.getString("menu", "EditCut"),
+				new MenuItemText( MOVE,
+								  _resource.getString("menu", "EditMove"),
 								  _resource.getString("menu",
-													  "EditCut-description"),
+													  "EditMove-description"),
 								  _listener),
 				new MenuItemText( COPY,
 								  _resource.getString("menu", "EditCopy"),
@@ -468,6 +475,11 @@ public class ContentMenuController {
 								  _resource.getString("menu",
 													  "EditPaste-description"),
 								  _listener),
+				new MenuItemText( 
+								  _resource.getString("menu", "EditMovePaste"),
+								  _resource.getString("menu",
+													  "EditMovePaste-description"),
+								  _listener),
 				new MenuItemText( DELETE,
 								  _resource.getString("menu", "EditDelete"),
 								  _resource.getString("menu",
@@ -1000,24 +1012,28 @@ public class ContentMenuController {
 		setEnabledMenuItem(_contextMenuItems, SET_REFERRALS, !isRootSelected);
 	}
 
-	private void updateCutCopyPasteMenuItems(boolean isRootSelected, 
-                                             boolean isSuffixSelected,
-											 boolean  isClipboardEmpty) {
+	private void updateMoveCopyPasteMenuItems(boolean isRootSelected, 
+                                              boolean isSuffixSelected,
+											  boolean isClipboardEmpty,
+											  boolean isDnInClipboardEmpty) {
 		setEnabledMenuItem(_editMenuItems, COPY, (!isRootSelected && !isSuffixSelected));
 		setEnabledMenuItem(_contextMenuItems, COPY, (!isRootSelected && !isSuffixSelected));
 		
-		setEnabledMenuItem(_editMenuItems, CUT, (!isRootSelected && !isSuffixSelected));
-		setEnabledMenuItem(_contextMenuItems, CUT, (!isRootSelected && !isSuffixSelected));
+		setEnabledMenuItem(_editMenuItems, MOVE, (!isRootSelected && !isSuffixSelected));
+		setEnabledMenuItem(_contextMenuItems, MOVE, (!isRootSelected && !isSuffixSelected));
 		
 		
 		setEnabledMenuItem(_editMenuItems, DELETE, (!isRootSelected && !isSuffixSelected));
 		setEnabledMenuItem(_contextMenuItems, DELETE, (!isRootSelected && !isSuffixSelected));
 		
-		setEnabledMenuItem(_editMenuItems, COPYDN, !isRootSelected);	
-		setEnabledMenuItem(_editMenuItems, COPYLDAPURL, !isRootSelected);	
-			
+		setEnabledMenuItem(_editMenuItems, COPYDN, !isRootSelected);
+		setEnabledMenuItem(_editMenuItems, COPYLDAPURL, !isRootSelected);
+
 		setEnabledMenuItem(_editMenuItems, PASTE, !isRootSelected && !isClipboardEmpty);
-		setEnabledMenuItem(_contextMenuItems, PASTE, !isRootSelected && !isClipboardEmpty);						
+		setEnabledMenuItem(_contextMenuItems, PASTE, !isRootSelected && !isClipboardEmpty);
+
+		setEnabledMenuItem(_editMenuItems, MOVEPASTE, !isRootSelected && !isDnInClipboardEmpty);
+		setEnabledMenuItem(_contextMenuItems, MOVEPASTE, !isRootSelected && !isDnInClipboardEmpty);
 	}
 
 	private void updatePWPMenuItems(Integer selectionPWPState, 
@@ -1136,8 +1152,9 @@ public class ContentMenuController {
 		//_shortCutTable.put(REFRESHTREE, KeyStroke.getKeyStroke(KeyEvent.VK_R, Event.CTRL_MASK));
         _shortCutTable.put(REFRESHNODE, KeyStroke.getKeyStroke(KeyEvent.VK_R, Event.CTRL_MASK));
 		_shortCutTable.put(COPY, KeyStroke.getKeyStroke(KeyEvent.VK_C, Event.CTRL_MASK));
-		_shortCutTable.put(CUT, KeyStroke.getKeyStroke(KeyEvent.VK_X, Event.CTRL_MASK));
+		_shortCutTable.put(MOVE, KeyStroke.getKeyStroke(KeyEvent.VK_M, Event.CTRL_MASK));
 		_shortCutTable.put(PASTE, KeyStroke.getKeyStroke(KeyEvent.VK_V, Event.CTRL_MASK));
+		_shortCutTable.put(MOVEPASTE, KeyStroke.getKeyStroke(KeyEvent.VK_W, Event.CTRL_MASK));
 		_shortCutTable.put(DELETE, KeyStroke.getKeyStroke(KeyEvent.VK_D, Event.CTRL_MASK));
 	}
 
@@ -1190,9 +1207,10 @@ public class ContentMenuController {
 	static final String ROLES = "roles";
 	static final String SET_REFERRALS = "referral";
 	static final String AUTHENTICATE = "authenticate";
-	static final String CUT = "cut";
+	static final String MOVE = "move";
 	static final String COPY = "copy";
 	static final String PASTE = "paste";
+	static final String MOVEPASTE = "movepaste";
 	static final String UNDO = "undo";
 	static final String DELETE = "delete";
 	static final String NEW_USER = "newuser";
