@@ -365,7 +365,10 @@ public class ChildrenController {
 	 */
 	public void setBaseNodeInfo(IBrowserNodeInfo node, boolean hasIndex) {
         _parentHasIndex = hasIndex;        
-		if (node == null) {
+		// We don't want to search for children of the
+		// root node since it doesn't represent an actual
+		// entry.
+		if ((node == null) || node.isRootNode()) {
 			_parentNode = null;
 		} else {
 			_parentNode = node.getNode();
