@@ -131,22 +131,19 @@ public 	class SuffixResourceObject extends DSResourceObject
 
 
     private void addSuffix(){
-	String psRDN = LDAPDN.explodeDN( _entry.getDN(), true)[0];
+	String suffix = MappingUtils.getMappingNodeSuffix(_entry);
+	String filter = MappingUtils.getParentSearchFilter(suffix);
 	try {
 	    _model.fireChangeFeedbackCursor(null, FeedbackIndicator.FEEDBACK_WAIT );
 	    LDAPConnection ldc = _model.getServerInfo().getLDAPConnection();
 	    LDAPSearchResults res =
 		ldc.search( "cn=mapping tree, cn=config",
-			    ldc.SCOPE_ONE,
-			    "(nsslapd-parent-suffix=" + 
-			    MappingUtils.Quote( psRDN ) +
-			    ")",
+			    ldc.SCOPE_ONE, filter,
 			    null,
 			    false );
 	    while( res.hasMoreElements() ) {
 		LDAPEntry bentry = (LDAPEntry)res.nextElement();
-		String name = bentry.getDN();
-		name = MappingUtils.unQuote(LDAPDN.explodeDN( bentry.getDN(), true)[0]);
+		String name = MappingUtils.getMappingNodeName(bentry);
 		_isLeaf = false ;
 		/* Add a node for each Instance */
 		SuffixResourceObject MapNode = 
@@ -155,13 +152,13 @@ public 	class SuffixResourceObject extends DSResourceObject
 	    }
 	} catch ( LDAPException e ) {
 	    if( e.getLDAPResultCode() != e.NO_SUCH_OBJECT ) {
-		String[] args_m = { psRDN , e.toString() };
+		String[] args_m = { suffix , e.toString() };
 		DSUtil.showErrorDialog( _model.getFrame(),
 					"error-find-subsuffix",
 					args_m,
 					SECTION);
 		Debug.println( "SuffixResourceObject.addSuffix: " + 
-			       "psRDN: " + psRDN +
+			       "suffix: " + suffix +
 			       "Error: " + e.toString());
 	    }
 	} finally {
@@ -180,12 +177,9 @@ public 	class SuffixResourceObject extends DSResourceObject
 	_model.fireChangeFeedbackCursor(null,
 					FeedbackIndicator.FEEDBACK_WAIT );
 	LDAPConnection ldc = _model.getServerInfo().getLDAPConnection();
-	String psRDN = LDAPDN.explodeDN( _entry.getDN(), true)[0];
-    psRDN = MappingUtils.escapeBackslash(psRDN);
-	String dbFilter = 
-	    "(&(objectclass=nsBackendInstance)" +
-	    "(nsslapd-suffix=" +
-	    MappingUtils.unQuote( psRDN )+ "))";
+	String suffix = MappingUtils.getMappingNodeSuffix(_entry);
+	String filter = MappingUtils.getSuffixSearchFilter(suffix, "nsslapd-suffix");
+	String dbFilter = "(&(objectclass=nsBackendInstance)" + filter + ")";
 
 	try {
 	    LDAPSearchResults res =
@@ -229,7 +223,7 @@ public 	class SuffixResourceObject extends DSResourceObject
 	    }
 	} catch ( LDAPException e ) {
 	    if( e.getLDAPResultCode() != e.NO_SUCH_OBJECT ) {
-		String[] args_m = { psRDN, e.toString() };
+		String[] args_m = { suffix, e.toString() };
 		DSUtil.showErrorDialog( _model.getFrame(),
 					"error-find-db",
 					args_m,
@@ -531,12 +525,10 @@ public 	class SuffixResourceObject extends DSResourceObject
     }
 
     private int delete_suffix(LDAPEntry node) {
-	String dn2delete = node.getDN();
-	String rdn2delete = (new DN(dn2delete)).explodeDN(true)[0];
-	String[] args = { rdn2delete };
+	String suffix = MappingUtils.getMappingNodeSuffix(node);
 
 	confirmDeleteSuffixPanel child =
-	    new confirmDeleteSuffixPanel( _model, dn2delete );
+	    new confirmDeleteSuffixPanel( _model, suffix );
 			
 	SimpleDialog dlg =
 	    new SimpleDialog( _model.getFrame(),
@@ -558,19 +550,19 @@ public 	class SuffixResourceObject extends DSResourceObject
 	StringBuffer sbDBLoc = new StringBuffer();	
 	switch( resDiag ) {
 	case confirmDeleteSuffixPanel.ALL: {
-	    del_all_suffix( ldc, dn2delete, sbDBLoc);
+	    del_all_suffix( ldc, suffix, node.getDN(), sbDBLoc);
 	    break;
 	}
 	case confirmDeleteSuffixPanel.ONE:
 	    LDAPAttribute dady_attr = node.getAttribute( "nsslapd-parent-suffix");
 	    if( dady_attr == null) {
-		del_1_suffix( ldc, dn2delete, null, true, sbDBLoc);
+		del_1_suffix( ldc, suffix, node.getDN(), null, true, sbDBLoc);
 	    } else {
 		Enumeration en = dady_attr.getStringValues();
 		if ( en.hasMoreElements() ) {
-		    del_1_suffix( ldc, dn2delete,
-				  (String)en.nextElement(), true,
-				  sbDBLoc );
+		    del_1_suffix( ldc, suffix,
+				  node.getDN(), (String)en.nextElement(),
+				  true, sbDBLoc );
 		}
 	    }
 	    break;
@@ -588,11 +580,10 @@ public 	class SuffixResourceObject extends DSResourceObject
 
     private int del_all_suffix( LDAPConnection ldc,
 				String dn2delete ,
-				StringBuffer sbDBLoc) {
-	String rdn2delete = (new DN(dn2delete)).explodeDN(true)[0];
-	String filter =
-	    "(&(objectclass=nsMappingTree)(nsslapd-parent-suffix=" + 
-	    rdn2delete +"))";		
+				String mndn, StringBuffer sbDBLoc) {
+	String filter = "(&(objectclass=nsMappingTree)" +
+		MappingUtils.getParentSearchFilter(dn2delete) +
+		")";
 	try {
 	    LDAPSearchResults res =
 		ldc.search( DSUtil.MAPPING_TREE_BASE_DN,
@@ -604,12 +595,12 @@ public 	class SuffixResourceObject extends DSResourceObject
 	    while(( res != null ) && res.hasMoreElements()) {
 		Vector v = new Vector();
 		LDAPEntry entry = (LDAPEntry)res.nextElement();
-		String dn2modify = entry.getDN();
-		del_all_suffix( ldc, dn2modify, sbDBLoc );
+		String dn2modify = MappingUtils.getMappingNodeSuffix(entry);
+		del_all_suffix( ldc, dn2modify, entry.getDN(), sbDBLoc );
 	    }
 	} catch( LDAPException e) {
 	    if( e.getLDAPResultCode() != e.NO_SUCH_OBJECT ) {
-		String[] args_m = { rdn2delete, e.toString() };
+		String[] args_m = { dn2delete, e.toString() };
 		DSUtil.showErrorDialog( _model.getFrame(),
 					"error-del-find-subsuffix",
 					args_m,
@@ -618,17 +609,16 @@ public 	class SuffixResourceObject extends DSResourceObject
 	    }	
 	}
 
-	return( del_1_suffix( ldc, dn2delete, null, false, sbDBLoc));	
+	return( del_1_suffix( ldc, dn2delete, mndn, null, false, sbDBLoc));	
 	    
     }
 
     private int del_1_suffix(LDAPConnection ldc,
 			     String dn2delete,
+			     String mndn,
 			     String dndady,
-			     boolean changeChildren,
-			     StringBuffer sbDBLoc) {
-	String arg = (new DN(dn2delete)).explodeDN(true)[0];
-	String[] dlg_arg = { arg };
+			     boolean changeChildren, StringBuffer sbDBLoc) {
+	String[] dlg_arg = { dn2delete };
 	GenericProgressDialog dlg = 
 	    new GenericProgressDialog(_model.getFrame(), 
 				      true, 
@@ -645,10 +635,10 @@ public 	class SuffixResourceObject extends DSResourceObject
 	    erase_one_suffix task = 
 		new erase_one_suffix( ldc,
 				      dn2delete,
+				      mndn,
 				      dndady,
 				      changeChildren,
-				      sbDBLoc,
-				      dlg );
+				      sbDBLoc, dlg );
 	    Thread th = new Thread(task);
 	    th.start();
 	    dlg.packAndShow();	    
@@ -661,36 +651,17 @@ public 	class SuffixResourceObject extends DSResourceObject
 	return( 1 );
     }
 
-
-    private boolean  isLeafMappingNode( ) {
-	DN pDN = new DN( _entry.getDN() );
-	String psRDN = LDAPDN.explodeDN( _entry.getDN(), true )[0];
-	String filter = "nsslapd-parent-suffix=" + MappingUtils.Quote( psRDN );
-	LDAPConnection ldc = _model.getServerInfo().getLDAPConnection();
-	try {
-	    LDAPSearchResults res = ldc.search( CONFIG_MAPPING, ldc.SCOPE_ONE,
-						filter, null, false);
-	    if (res == null || !res.hasMoreElements()) {
-		return( true );
-	    } else {
-		return( false );
-	    }
-	} catch (LDAPException e) {
-	    Debug.println( "SuffixResourceObject.isLeafMappingNode() : error :" + e );
-	    return( false );
-	}
-    }
-
     class erase_one_suffix implements  Runnable {
 
 	public erase_one_suffix(LDAPConnection ldc,
 				String dn2delete,
+				String mndn,
 				String dndady,
 				boolean changeChildren,
-				StringBuffer sbDBLoc,
-				GenericProgressDialog dlg ) {
+				StringBuffer sbDBLoc, GenericProgressDialog dlg ) {
 	    _ldc = ldc;
 	    _dn2delete = dn2delete;
+	    _mndn = mndn;
 	    _dndady = dndady;
 	    _changeChildren = changeChildren;
 	    _dlg = dlg;
@@ -701,11 +672,10 @@ public 	class SuffixResourceObject extends DSResourceObject
 	public void run() {
 	    boolean  everythingUnderControl = true;
 	    if ( _changeChildren ) {
-		String rdn2delete = (new DN(_dn2delete)).explodeDN(true)[0];
-		rdn2delete = MappingUtils.escapeBackslash(rdn2delete);        
-		String filter =
-		    "(&(objectclass=nsMappingTree)(nsslapd-parent-suffix=" + 
-		    rdn2delete +"))";		
+		String filter = "(&(objectclass=nsMappingTree)" +
+			MappingUtils.getParentSearchFilter(_dn2delete) +
+			")";
+		String suffix2delete = _dn2delete;
 		try {
 		    LDAPSearchResults res =
 			_ldc.search( DSUtil.MAPPING_TREE_BASE_DN,
@@ -722,9 +692,9 @@ public 	class SuffixResourceObject extends DSResourceObject
 			if( _dndady  == null ) {
 			    attrs.add( LDAPModification.DELETE,
 				       new LDAPAttribute( "nsslapd-parent-suffix",
-							  rdn2delete ));
+							  suffix2delete ));
 			} else {
-			    rdn2delete = _dndady;
+			    suffix2delete = _dndady;
 			    attrs.add( LDAPModification.REPLACE,
 				       new LDAPAttribute( "nsslapd-parent-suffix",
 							  _dndady));
@@ -740,14 +710,14 @@ public 	class SuffixResourceObject extends DSResourceObject
 						   SECTION);
 			    
 			    Debug.println("SuffixResourceObject.del_1_suffix(): " +
-					  "rdn2 delete or mod = " + rdn2delete );
+					  "rdn2 delete or mod = " + suffix2delete );
 			    
 			    everythingUnderControl = false;
 			}
 		    }
 		} catch(LDAPException e) {
 		    if( e.getLDAPResultCode() != e.NO_SUCH_OBJECT ) {
-			String[] args_m = { rdn2delete, e.toString() };
+			String[] args_m = { suffix2delete, e.toString() };
 			DSUtil.showErrorDialog( _model.getFrame(),
 						"error-del-find-subsuffix",
 						args_m,
@@ -763,8 +733,8 @@ public 	class SuffixResourceObject extends DSResourceObject
 		this._dlg.closeCallBack();
 	    }
 
-	    if (!DSUtil.deleteTree ( _dn2delete, _ldc, false, _dlg )) {
-		String[] args_m = { _dn2delete } ;
+	    if (!DSUtil.deleteTree ( _mndn, _ldc, false, _dlg )) {
+		String[] args_m = { _mndn } ;
 		DSUtil.showErrorDialog( _model.getFrame(),
 				        "error-remove",
 				        args_m,
@@ -776,13 +746,11 @@ public 	class SuffixResourceObject extends DSResourceObject
 		// check suffix 
 		this._dlg.stepCompleted(1);
 
-		/* now get ride of all its database */
+		/* now get rid of all its database */
 		
-		String rdn2delete = (new DN(_dn2delete)).explodeDN(true)[0];
-		rdn2delete = MappingUtils.escapeBackslash(rdn2delete);
-		String filter =
-		    "(&(objectclass=nsBackendInstance)(nsslapd-suffix=" +
-		    MappingUtils.unQuote(rdn2delete) +"))";
+		String filter = "(&(objectclass=nsBackendInstance) " +
+			MappingUtils.getSuffixSearchFilter(_dn2delete, "nsslapd-suffix") +
+			")";
 		try {
 		    LDAPSearchResults res = 
 			_ldc.search( DSUtil.PLUGIN_CONFIG_BASE_DN,
@@ -804,7 +772,7 @@ public 	class SuffixResourceObject extends DSResourceObject
 		    }
 		} catch (LDAPException lde) {
 		    if( lde.getLDAPResultCode() != lde.NO_SUCH_OBJECT ) {
-			String[] args_m = { rdn2delete, lde.toString() };
+			String[] args_m = { _dn2delete, lde.toString() };
 			DSUtil.showErrorDialog( _model.getFrame(),
 						"error-del-find-subsuffix",
 						args_m,
@@ -826,8 +794,9 @@ public 	class SuffixResourceObject extends DSResourceObject
 	}
 
 	LDAPConnection	_ldc;
-	String		_dn2delete;
-	String		_dndady;
+	String		_dn2delete; // the suffix DN i.e. dc=example,dc=com
+	String          _mndn; // the DN of the mapping tree node e.g. cn=dc\3Dexample\2Cdc\3Dcom,cn=mapping tree,cn=config
+	String		_dndady; // the parent suffix, if any
 	boolean		_changeChildren;
 	GenericProgressDialog _dlg;
 	StringBuffer _sbDBLoc;
