@@ -251,7 +251,7 @@ public class EncryptionPanel extends BlankPanel
 			else if (_rbRequired.isSelected()) {
 				_configData.clientAuth = _configData.CLIENT_AUTH_REQUIRED;
 			}
-			_configData.sslConsoleOn = _cbConsoleSSL.isSelected();
+			_configData.sslConsoleOn = _configData.sslServerOn && _cbConsoleSSL.isSelected();
 			_configData.sslCheckHostName = _cbSSLCheckHostName.isSelected();
 
 			// Write the config data to the directories
@@ -415,8 +415,8 @@ public class EncryptionPanel extends BlankPanel
 		Frame f = getModel().getFrame();
 		CipherPreferenceDialog dlg;
 
-		Debug.println(4, 
-			"EncryptionPanel.showCipherPreferenceDialog: cipher = " + cipher);
+		Debug.println(4, "EncryptionPanel.showCipherPreferenceDialog: cipher = " + cipher);
+		Debug.println(4, "EncryptionPanel.showCipherPreferenceDialog: TLS_OFF = " + _configData.CIPHER_TLS_OFF);
 		dlg = new CipherPreferenceDialog(f, null, _configData.CIPHER_SSL3_OFF, _configData.CIPHER_TLS_OFF);
 		dlg.setCipherEnabled(dlg.SSL_V3, _configData.cipherPrefs);
 		dlg.setCipherEnabled(dlg.SSL_TLS, _configData.cipherPrefs);
@@ -447,6 +447,8 @@ public class EncryptionPanel extends BlankPanel
 		Debug.println(4, 
 			"EncryptionPanel.securityEnabledChanged: enable = " + enable);
 		_configData.sslServerOn = enable;
+		_configData.sslConsoleOn = enable;
+
 		// We must enable/disable the components accordingly.
 		updateComponentState();
 		setDirty(true);
@@ -772,11 +774,13 @@ class EncryptionConfigData {
 										  "-fortezza_null";
 
 	// Cipher list to build the TLS tab in the cipher dialog
-	static final String CIPHER_TLS_OFF =  "-tls_rsa_export1024_with_rc4_56_sha," +
+	static final String CIPHER_TLS_OFF =  "+all," +
+	                                      "-tls_rsa_export1024_with_rc4_56_sha," +
 	                                      "-tls_rsa_export1024_with_des_cbc_sha," +
 	                                      "-tls_rsa_aes_128_sha," +
-	                                      "-tls_rsa_aes_256_sha";
-										  
+	                                      "-tls_rsa_aes_256_sha," +
+	                                      "-TLS_RSA_WITH_AES_128_GCM_SHA256";
+
 	// Reads the directory and initializes this instance
 	public void readFromDirectory(LDAPConnection ldc, LDAPConnection sieldc, String sieDn)
 	throws LDAPException {
@@ -896,7 +900,7 @@ class EncryptionConfigData {
 				attrs.add(new LDAPAttribute("nsssltoken", setup.selectedDevice));
 			if (setup.selectedCertificate.length() >= 1) {                        
 
-				// Strip off the "<token>:" prefix for certs on extrnal tokens
+				// Strip off the "<token>:" prefix for certs on external tokens
 				String cert = setup.selectedCertificate;
 				String tokenPrefix = setup.selectedDevice + ":";
 				if (cert.startsWith(tokenPrefix)) {
@@ -919,7 +923,7 @@ class EncryptionConfigData {
 		//		cn=encryption,cn=config
 		LDAPModificationSet modSet = new LDAPModificationSet();
 		String v = sslServerOn ? "on" : "off";
-		modSet.add(LDAPModification.REPLACE, new LDAPAttribute("nsssl3", v));
+		modSet.add(LDAPModification.REPLACE, new LDAPAttribute("nsTLS1", v));
 		switch(clientAuth) {
 			case CLIENT_AUTH_ALLOWED:
 				v = "allowed";
