@@ -1028,6 +1028,22 @@ public class IndexManagementPanel extends BlankPanel {
 		dumpVector( "fillRow in " + str, v );
 		Vector vals = new Vector();
 		if ( v != null ) {
+			// If the attribute contains an index type to be skipped,
+			// e.g., "subtree", the index won't be displayed on the
+			// index table 
+			for (int i = 0; i < v.size(); i++) {
+				String s = (String)v.elementAt(i);
+				int j = 0;
+				for (; j < SKIPFILTERS.length; j++) {
+					if ( s.equals(SKIPFILTERS[j]) ) {
+						break;
+					}
+				}
+				if (j < SKIPFILTERS.length) {
+					return;
+				}
+			}
+
 			initRow(str, vals);
 			dumpVector( "fillRow after initRow " + str, vals );
 
@@ -1312,6 +1328,7 @@ public class IndexManagementPanel extends BlankPanel {
 	static final private String DN_PREFIX = "cn=index,cn=config,cn=ldbm database,cn=plugins,cn=config";
 	/* The FILTERS order must be the same as headings in the properties file */
 	static final private String[] FILTERS = {"approx", "eq", "pres", "sub"};
+	static final private String[] SKIPFILTERS = {"subtree"};
 	// Object classes of an index entry
 	static final private String[] OCLASSES = { "top", "nsIndex" };
 
