@@ -38,6 +38,53 @@ public class MappingUtils {
 
     private MappingUtils() {}
 
+    /**
+     * The mapping node name is the suffix DN.  In the mapping tree entry,
+     * the values of the cn attribute hold the suffix DN.  There are usually two
+     * values - the quoted or escaped value, and the unquoted value.  We look
+     * for the first unquoted value and use that for the node name.  If for some
+     * reason we could not find the cn attribute or a suitable value, assume the
+     * suffix is the value of the leftmost RDN in the entry DN.
+     * @param mnent - the mapping tree node entry
+     * @return the suffix to use as the name of the mapping tree node
+     */
+    static public String getMappingNodeName(LDAPEntry mnent) {
+	String cnvals[] = DSUtil.getAttrValues(mnent, "cn");
+	String suffixval = null;
+	for (int ii = 0; (cnvals != null) && (ii < cnvals.length); ++ii) {
+	    if (!DSUtil.DNUsesLDAPv2Quoting(cnvals[ii])) {
+	        suffixval = DSUtil.unEscapeDN(cnvals[ii]);
+	        break;
+	    }
+	}
+	if (suffixval == null) {
+	    suffixval = DSUtil.unEscapeRDNVal(LDAPDN.explodeDN(mnent.getDN(),true)[0]);
+	}
+	return suffixval;
+    }
+    
+    /**
+     * Given a mapping tree node entry, return the suffix that this represents.
+     * @param mnent - the mapping tree node entry
+     * @return the suffix represented by this mapping tree node
+     */
+    static public String getMappingNodeSuffix(LDAPEntry mnent) {
+	return getMappingNodeName(mnent);
+    }
+    
+    static public String getSuffixSearchFilter(String suffix, String attrname) {
+	String normsuffix = LDAPDN.normalize(suffix);
+	return "(|(" + attrname + "=" + suffix + ")(" + attrname + "=" + Quote(suffix) + ")(" +
+		attrname + "=" + normsuffix + ")(" + attrname + "=" + Quote(normsuffix) + "))";
+    }
+
+    static public String getSuffixSearchFilter(String suffix) {
+	return getSuffixSearchFilter(suffix, "cn");
+    }
+    static public String getParentSearchFilter(String suffix) {
+	return getSuffixSearchFilter(suffix, "nsslapd-parent-suffix");
+    }
+
     static public String[] getMappingNode(LDAPConnection ldc ) {
 	Vector v = new Vector(1);
 
@@ -51,8 +98,8 @@ public class MappingUtils {
 			    false );
 	    while( res.hasMoreElements() ) {
 		LDAPEntry bentry = (LDAPEntry)res.nextElement();
-		String name = bentry.getDN();
-		v.addElement(unQuote(LDAPDN.explodeDN(bentry.getDN(),true)[0]));
+		String name = getMappingNodeSuffix(bentry);
+		v.addElement(name);
 	    }
 	} catch ( LDAPException e ) {
 	    Debug.println(0, "NewMappingNodePanel.getMappingNode() " + e );
@@ -62,32 +109,12 @@ public class MappingUtils {
 	return mapList;
     }
 
-    static public String unQuote( String line ) {
-	if (line != null) {
-	    if (line.length() > 0) {
-		StringBuffer unquote_line = new StringBuffer();
-				
-		Character deb = new Character( line.charAt(0) );
-		Character fin = new Character( line.charAt( line.length() - 1 ) );
-		Character tag = new Character( '"' );
-				
-		if ( deb.compareTo(tag) ==  0) {
-		    for (int i=1; i < (line.length() - 1); i++) {
-			unquote_line.append(line.charAt(i));
-		    }
-		} else {
-		    unquote_line.append( line );
-		}			
-		return(unquote_line.toString());
-	    }
-	    return (new String(line));
-	}
-	return null;
-    }
-
     static public String Quote( String line ) {
+	if ((line == null) || (line.length() < 1)) {
+	    return "\"\"";
+	}
 	StringBuffer quoted_line = new StringBuffer();
-		
+
 	Character deb = new Character( line.charAt(0) );
 	Character tag = new Character( '"' );
 
@@ -101,51 +128,6 @@ public class MappingUtils {
 	return(quoted_line.toString());
     }
 
-    /** 
-     * Escape backslashes in RDNs for suffix search. E.g. to search for 
-     * "o=Abc\,Inc" as an attribute value it should be eacaped as
-     * "o=Abc\\,Inc" in a search filter (nsslapd-suffix=o=Abc\\,Inc).
-     */
-    static public String escapeBackslash(String val) {
-        if (val.indexOf('\\') < 0) {
-            return val;
-        }
-        StringBuffer res = new StringBuffer();
-        for (int i=0; i < val.length(); i++) {
-            if (val.charAt(i) == '\\') {
-                res.append('\\');
-            }
-            res.append(val.charAt(i));
-        }
-        return res.toString();
-    }
-
-    /**
-     * Remove escape backslashes. This will be used when creating a suffix
-     * to convert a RDN with escaped characters into an attribute value.
-     * 
-     * E.g. the user wants to create a domain for "Abc, Inc". The domain
-     * suffix DN must be input as "o=Abc\, Inc", but when the suffix entry
-     * is created the corresponding attr value is "Abc, Inc".
-     */    
-    static public String unescapeBackslash(String val) {
-        if (val.indexOf('\\') < 0) {
-            return val;
-        }
-        StringBuffer res = new StringBuffer();
-        for (int i=0; i < val.length(); i++) {
-            if (val.charAt(i) == '\\') {
-                if (++i < val.length()) {
-                    res.append(val.charAt(i));
-                }
-            }
-            else {
-                res.append(val.charAt(i));
-            }
-        }
-        return res.toString();        
-    }
-
     static public String[] getBackendList(LDAPConnection ldc) {
 	if (ldc == null) {
 	    return null;
@@ -226,7 +208,7 @@ public class MappingUtils {
 	return suffixes;
     }
 
-    /* Uses the bubble method to order the suffixes (the longuest goes first)*/
+    /* Uses the bubble method to order the suffixes (the longest goes first)*/
 
     static public void orderSuffixes(String[] suffixes) {
 	if (suffixes==null) {
@@ -328,13 +310,13 @@ public class MappingUtils {
 			    int index = values[i].indexOf(':');
 			    if (index > 0) {
 				String suffix = values[i].substring(index+1);
-				v.addElement(MappingUtils.unQuote(suffix));
+				v.addElement(suffix);
 			    }
 			}			
 		    }		
 		} else {
 		    String suffix = DSUtil.getAttrValue(entry, SUFFIX_ATTR);
-		    v.addElement(MappingUtils.unQuote(suffix));
+		    v.addElement(suffix);
 		}
 	    }
 	} catch ( LDAPException e ) {
@@ -601,40 +583,23 @@ public class MappingUtils {
 					 ) {
 	int resDiag;
 
-	StringBuffer cn2add = new StringBuffer();
-
 	// Check parms
 	if( (newNodeName == null) || (newNodeName.trim().length() == 0) ) {
 	    return( false );
 	}
 
-	// build the cn
-	Character deb = new Character(newNodeName.charAt(0));
-	Character fin = new Character(newNodeName.charAt(newNodeName.length() - 1));
-	Character tag = new Character( '"' );
-
-	if ( deb.compareTo(tag) !=  0) {
-	    cn2add.append( '"' );
-	} 		
-
-	cn2add.append( newNodeName );
-
+	StringBuffer cn2add = new StringBuffer(newNodeName);
 	// Add the upperNode to the new node
 	if ( upperNode.compareTo( ROOT_MAPPING_NODE )!=0 ) {
 	    cn2add.append( "," );
 	    cn2add.append( upperNode );
 	}
 
+	// Building dn to add in mapping tree 
+	// NOTE: we only need the escaped value in the DN - we use the 
+	// "raw" value everywhere else
+	String dn2add  = "cn=" + DSUtil.escapeDNVal(cn2add.toString()) + "," + CONFIG_MAPPING ;
 
-	if ( fin.compareTo(tag) != 0) {
-	    cn2add.append( '"' );
-	}
-		
-
-	// Building dn to add in mapping tree
-	String dn2add  = "cn=" + cn2add.toString() + "," + CONFIG_MAPPING ;
-		
-		
 	// Start LDAP job
 	LDAPAttributeSet attrs = new LDAPAttributeSet();
 
@@ -644,13 +609,14 @@ public class MappingUtils {
 	String state[] = { NStatus };
 	attrs.add( new LDAPAttribute( "nsslapd-state", state ));
 
-	// Force a quoted value just to have a consistent display
+	// cn value is the "raw" suffix
+	// the server may also add the value from the RDN value from the DN
 	String mycn[] = { cn2add.toString() };
 	attrs.add( new LDAPAttribute( "cn", mycn ));
 
-
 	if ( upperNode.compareTo( ROOT_MAPPING_NODE ) != 0) {
-	    String dady[] = { Quote( upperNode.trim() ) };
+	    // parent suffix is also the "raw" value, not escaped or quoted
+	    String dady[] = { upperNode.trim() };
 	    attrs.add( new LDAPAttribute( "nsslapd-parent-suffix", dady ));
 	}
 
@@ -905,6 +871,49 @@ public class MappingUtils {
 	
     }
 
+    public static boolean isLeafMappingNode(LDAPConnection ldc, LDAPEntry _entry) {
+	String suffix = MappingUtils.getMappingNodeSuffix(_entry);
+	String filter = MappingUtils.getParentSearchFilter(suffix);
+	// this node is a leaf if it is not the parent of another node
+	try {
+	    LDAPSearchResults res = ldc.search( CONFIG_MAPPING, LDAPv3.SCOPE_ONE,
+		    filter, null, false);
+	    if ((res == null) || !res.hasMoreElements()) {
+		return( true );
+	    } else {
+		return( false );
+	    }
+	} catch (LDAPException e) {
+	    Debug.println( "MappingNodeObject.isLeafMappingNode() :" + e );
+	    return( false );
+	}
+    }
+
+    /**
+     * Given a suffix DN, return the corresponding mapping tree node DN
+     * @param ldc the LDAP connection
+     * @param suffix the suffix DN
+     * @return the DN of the mapping tree node corresponding to this suffix
+     */
+    public static String getMappingNodeForSuffix(LDAPConnection ldc, String suffix) {
+	String filter = getSuffixSearchFilter(suffix);
+	// this node is a leaf if it is not the parent of another node
+	String mndn = null;
+	try {
+	    LDAPSearchResults res = ldc.search( CONFIG_MAPPING, LDAPv3.SCOPE_ONE,
+		    filter, null, false);
+	    if ((res == null) || !res.hasMoreElements()) {
+		Debug.println( "MappingNodeObject.getMappingNodeForSuffix() : " +
+			"no entries returned for filter " + filter );
+	    } else {
+		LDAPEntry entry = (LDAPEntry)res.nextElement();
+		mndn = entry.getDN();
+	    }
+	} catch (LDAPException e) {
+	    Debug.println( "MappingNodeObject.getMappingNodeForSuffix() :" + e );
+	}
+	return mndn;
+    }
 
     private final static String _section = "mappingtree";
     public static final String CONFIG_BASEDN = "cn=plugins, cn=config" ;
