@@ -102,11 +102,7 @@ public class NewChainingPanel extends BlankPanel
 
 	HostPanel.setLayout(HLbag);
 
-	LDAPAttribute suffixCN = _entrySuffix.getAttribute("cn");
-	if ( suffixCN != null ){
-	    _suffix = MappingUtils.unQuote( suffixCN.getStringValueArray()[0]);
-	} 
-
+	_suffix = MappingUtils.getMappingNodeSuffix(_entrySuffix);
 	_suffixLabel =  makeJLabel( _section, "suffix-name" );
 	HLgbc.fill		= HLgbc.NONE;
 	HLgbc.weightx	= 0;
@@ -721,7 +717,7 @@ public class NewChainingPanel extends BlankPanel
 	}
     }									 
 
-    public int addChainingBackend(String _MappingNode ) {
+    public int addChainingBackend(String suffix ) {
 
 	String _instName = _instanceNameText.getText().trim();
 	getChainingLoc();
@@ -741,7 +737,7 @@ public class NewChainingPanel extends BlankPanel
 	attrs.add( new LDAPAttribute( "cn", cn_dbInst ) );
 
 				   
-	String suffix_dbInstConfig[] = { _MappingNode };
+	String suffix_dbInstConfig[] = { suffix };
 	attrs.add( new LDAPAttribute ( "nsslapd-suffix", suffix_dbInstConfig ));
 
 	String nsBindDN = _bindDNText.getText();
