@@ -250,12 +250,17 @@ public class RestorePanel extends BlankPanel {
 		if (_tfExport.getText().trim().equals("")) {
 			setOkay(false);
 		} else {
-			File f = new File(_tfExport.getText());
-			if (!f.exists()) { // Restore path must exist
-				setOkay(false);
-			} else if (!f.isDirectory()) { // Restore path must be a directory
-				setOkay(false);
+			if ( isLocal() ){
+				File f = new File(_tfExport.getText());
+				if (!f.exists()) { // Restore path must exist
+					setOkay(false);
+				} else if (!f.isDirectory()) { // Restore path must be a directory
+					setOkay(false);
+				} else {
+					setOkay(true);
+				}
 			} else {
+				// This is a remote session, let the server validate the path
 				setOkay(true);
 			}
 		}
