@@ -745,7 +745,7 @@ public class SchemaAttributesPanel extends BlankPanel
     private AttrTableModel _userDefTableModel = null;
     private AttrTableModel _stdTableModel = null;
 
-	private static int _widths[] = { 130, 160, 115, 40 };
+	private static int _widths[] = { 130, 160, 115, 40, 40, 40, 40 };
 	/* Index of multi/single checkbox column */
 	private final static int MULTI_INDEX = 3;
 	private static Hashtable _htSyntaxStrings = null;
