@@ -250,15 +250,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 		gbc.gridwidth = gbc.REMAINDER;
 		gbc.weightx = 1.0;
 		purgeDelayPanel.add(Box.createHorizontalGlue(), gbc);
-		
-		_cb4xConsumer = makeJCheckBox(_section, "4xcompatible", false, _resource);
-		_cb4xConsumer.setToolTipText(_resource.getString( "replication-replica-4xcompatible",
-														 "ttip"));
-		gbc.gridwidth = gbc.RELATIVE;
-		gbc.anchor = gbc.NORTHWEST;
-		consumerTypePanel.add(_cb4xConsumer, gbc);	
-		gbc.gridwidth = gbc.REMAINDER;
-		consumerTypePanel.add(Box.createHorizontalGlue(), gbc);
    }
 
 
@@ -438,7 +429,6 @@ public class ReplicaSettingPanel extends BlankPanel {
         _saveWindowsSyncEnabled = false;
 
 		_saveDS5ReplicaTypeExist = false;
-		_saveDS5ReplicaLegacyConsumerExist = false;
 		_saveReplicaIDExist = false;
 		_saveReplicaIDExist = false;
 		_saveBindDNExist = false;
@@ -452,7 +442,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 		_saveBindDNList = new Vector();
 		_saveDS5Flags = true;
 		_saveReferralList = new Vector();
-		_save4xConsumer = false;
 
 		_saveIsSimpleMaster = false;
 		_saveIsSlave = false;
@@ -480,14 +469,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 				_saveDS5ReplicaTypeExist = true;
 			}			
 
-			// nsds5ReplicaLegacyConsumer			
-			valattr = DSUtil.getAttrValue( replicaEntry, ReplicationTool.REPLICA_LEGACY_CONSUMER_ATTR );
-			_save4xConsumer = (valattr.length() != 0) &&
-				valattr.equalsIgnoreCase("on");				
-			if (valattr.length() != 0) {
-				_saveDS5ReplicaLegacyConsumerExist = true;
-			}
-
 			// nsds5ReplicaPurgeDelay		
 			valattr = DSUtil.getAttrValue( replicaEntry, ReplicationTool.REPLICA_PURGE_DELAY_ATTR );
 			if( valattr.length() != 0 ) {
@@ -581,7 +562,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 					  "_saveBindDNExist = "+_saveBindDNExist+"\n"+
 					  "_saveReferralListExist = "+_saveReferralListExist+"\n"+
 					  "_savePurgeDelayExist = "+_savePurgeDelayExist+"\n"+
-					  "_save4xConsumer = "+_save4xConsumer+"\n"+
 					  "_saveDS5FlagsExist = "+_saveDS5FlagsExist+"\n"+
 					  "_saveReadOnly = "+_saveReadOnly+"\n"+
 					  "_savePurgeDelay = "+_savePurgeDelay+"\n"+
@@ -636,11 +616,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 		for (int i=0; i<_saveReferralList.size(); i++) {
 			_referralListData.addElement(_saveReferralList.elementAt(i));
 		}
-		if (_save4xConsumer) {			
-			_cb4xConsumer.setSelected(true);
-		} else {
-			_cb4xConsumer.setSelected(false);
-		}
 	}
 
 	private void populatePurgeDelay(String time) {
@@ -679,36 +654,12 @@ public class ReplicaSettingPanel extends BlankPanel {
 		}		
 		Object source = e.getSource();
 
-		/* If the user tries to define a 4.x Consumer, the legacy settings are needed.
-		   That's why we see if the legacy settings entry exists or not.
-		   If the legacy settings entry does not exist we display an error message telling 
-		   the user that he/she has to define the legacy settings first.  In this dialog we 
-		   describe the steps to follow */				
-		if (source.equals(_cb4xConsumer) && _cb4xConsumer.isSelected()) {	
-			boolean legacyEntryExists = false;
-			try {
-				LDAPConnection ldc = _model.getServerInfo().getLDAPConnection();		
-				String[] attrs = {"dn"};
-				LDAPEntry entry = ldc.read(LegacyConsumerSettingPanel.REPSETTINGS_DN, attrs);
-				if (entry != null) {
-					legacyEntryExists = true;
-				}
-			} catch (LDAPException lde) {
-			}
-			if (!legacyEntryExists) {				
-				_cb4xConsumer.setSelected(false);
-				DSUtil.showErrorDialog( _model.getFrame(),
-										"enable-legacy-error",
-										(String[])null,
-										_section,
-										_resource);								
-			}
 		/* If the user tries to define a master or a hub, we need to log the changes.
 		   That's why we see if the change log entry exists or not.
 		   If the change log entry does not exist we display an error message telling 
 		   the user that he/she has to define the Change Log first.  In this dialog we 
 		   describe the steps to follow */
-		} else if ((source.equals(_rbIsSimpleMaster) &&
+		if ((source.equals(_rbIsSimpleMaster) &&
 			 _rbIsSimpleMaster.isSelected()) ||
 			(source.equals(_rbIsMultiMaster) &&
 			 _rbIsMultiMaster.isSelected()) ||
@@ -971,43 +922,7 @@ public class ReplicaSettingPanel extends BlankPanel {
 	  */
 	private boolean saveConfirmationDialog() {
 		boolean confirmation = true;
-		if (_cbReplicaEnabled.isSelected() &&
-			_cb4xConsumer.isSelected()) {
-		
-			/* The user is defining a multi master that can be updated by a 4.X server.
-			   With this configuration the replica won't accept client modifications. */
-			if (_rbIsMultiMaster.isSelected()) {
-				int option = DSUtil.showConfirmationDialog(
-														   _model.getFrame(),
-														   "confirm-multimaster-4xcompatible",
-														   "",
-														   _section,
-														   _resource);
-				if (option != JOptionPane.YES_OPTION) {
-					confirmation = false;
-				} 
-			} else if (_rbIsSimpleMaster.isSelected()) {
-				int option = DSUtil.showConfirmationDialog(
-														   _model.getFrame(),
-														   "confirm-simplemaster-4xcompatible",
-														   "",
-														   _section,
-														   _resource);
-				if (option != JOptionPane.YES_OPTION) {
-					confirmation = false;
-				} 
-			} else {
-				int option = DSUtil.showConfirmationDialog(
-														   _model.getFrame(),
-														   "confirm-readonly-4xcompatible",
-														   "",
-														   _section,
-														   _resource);
-				if (option != JOptionPane.YES_OPTION) {
-					confirmation = false;
-				}
-			}			
-		} else if (_rbIsSlave.isSelected() &&
+		if (_rbIsSlave.isSelected() &&
 				   !_saveIsSlave &&
 				   _saveReplicaEnabled &&
 				   hasReplicationAgreements()) {
@@ -1207,14 +1122,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 								 value);
 		attrSet.add(attr);
 
-		// nsds5ReplicaLegacyConsumer		
-		if (_cb4xConsumer.isSelected()) {
-			value = "on";
-			attr = new LDAPAttribute(ReplicationTool.REPLICA_LEGACY_CONSUMER_ATTR,
-									 value);
-			attrSet.add(attr);
-		}
-
 		// ndsDS5flags
 		/* If we are a slave we DON'T log changes */
 		if (!_rbIsSlave.isSelected()) {
@@ -1332,22 +1239,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 										 value));
 		}
 
-		// nsds5ReplicaLegacyConsumer	
-		modType = _saveDS5ReplicaLegacyConsumerExist?LDAPModification.REPLACE:LDAPModification.ADD;
-		if (_cb4xConsumer.isSelected() &&
-			!_save4xConsumer ) {
-			value = "on";
-			modSet.add(modType,
-					   new LDAPAttribute(ReplicationTool.REPLICA_LEGACY_CONSUMER_ATTR,
-										 value));		
-		} else if (!_cb4xConsumer.isSelected() &&
-				   _save4xConsumer) {
-			value = "off";
-			modSet.add(modType,
-					   new LDAPAttribute(ReplicationTool.REPLICA_LEGACY_CONSUMER_ATTR,
-										 value));	
-		}
-		
 		// ndsDS5flags
 		/* If we are a slave we DON'T log changes */
 		modType = _saveDS5FlagsExist?LDAPModification.REPLACE:LDAPModification.ADD;
@@ -1700,13 +1591,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 				isPurgeDelayDirty = true;
 			}
 		}
-
-		/* Check the 4x compatibility */
-		boolean is4xCompatibleDirty = false;
-		if (_cb4xConsumer.isSelected() != _save4xConsumer) {
-			is4xCompatibleDirty = true;			
-		}
-
 		/* Check the supplier DN field */
 		boolean isBindDNListDirty = false;
 		boolean isBindDNListValid = true;
@@ -1748,13 +1632,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 		} else {
 			setChangeState(_lBindDNList, CHANGE_STATE_UNMODIFIED);
 		}
-		
-		if (is4xCompatibleDirty) {	
-			setChangeState( _cb4xConsumer, CHANGE_STATE_MODIFIED );	
-		} else {	
-			setChangeState( _cb4xConsumer, CHANGE_STATE_UNMODIFIED);	
-		}
-
 		if (!isPurgeDelayValid) {
 			setChangeState(_lPurgeDelay, CHANGE_STATE_ERROR );
 			setChangeState(_cbPurgeDelayNever, CHANGE_STATE_ERROR );
@@ -1780,7 +1657,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 		}
 
 		if (isReplicaIDDirty ||			
-			is4xCompatibleDirty ||
 			isBindDNListDirty ||
 			isPurgeDelayDirty ||
 			isReferralListDirty ||
@@ -1887,7 +1763,6 @@ public class ReplicaSettingPanel extends BlankPanel {
 
 	private JCheckBox _cbReplicaEnabled = null;
 	private JCheckBox _cbPurgeDelayNever = null;
-	private JCheckBox _cb4xConsumer = null;
 
 	private JRadioButton _rbIsSimpleMaster = null;
 	private JRadioButton _rbIsSlave = null;
@@ -1918,7 +1793,6 @@ public class ReplicaSettingPanel extends BlankPanel {
     private boolean _saveReferralListExist = false;
     private boolean _savePurgeDelayExist = false;
 	private boolean _saveDS5FlagsExist = false;
-	private boolean _saveDS5ReplicaLegacyConsumerExist = false;
 
     private JLabel _lBindDNList = null;
 	private JLabel _lReferralList = null; 
@@ -1934,11 +1808,8 @@ public class ReplicaSettingPanel extends BlankPanel {
 	private boolean _saveIsHub = false;
 	private boolean _saveReadOnly = false;
 	private boolean _saveReplicaEnabled = false;
-        private boolean _saveWindowsSyncEnabled = false;
+	private boolean _saveWindowsSyncEnabled = false;
 	private boolean _saveDS5Flags = false;
-	private boolean _save4xConsumer = false;
-        
-       
 
 	/* These members, tell which are the values in the server (or the default values
 	   if there are no values on the server) */
