@@ -238,15 +238,6 @@ public class WindowsSyncSettingPanel extends BlankPanel {
         gbc.gridwidth = gbc.REMAINDER;
         gbc.weightx = 1.0;
         purgeDelayPanel.add(Box.createHorizontalGlue(), gbc);
-        
-        _cb4xConsumer = makeJCheckBox(_section, "4xcompatible", false, _resource);
-        _cb4xConsumer.setToolTipText(_resource.getString( "replication-replica-4xcompatible",
-        "ttip"));
-        gbc.gridwidth = gbc.RELATIVE;
-        gbc.anchor = gbc.NORTHWEST;
-        consumerTypePanel.add(_cb4xConsumer, gbc);
-        gbc.gridwidth = gbc.REMAINDER;
-        consumerTypePanel.add(Box.createHorizontalGlue(), gbc);
     }
     
     
@@ -587,11 +578,6 @@ public class WindowsSyncSettingPanel extends BlankPanel {
                 for (int i=0; i<_saveReferralList.size(); i++) {
                     _referralListData.addElement(_saveReferralList.elementAt(i));
                 }
-        //        if (_save4xConsumer) {
-        //            _cb4xConsumer.setSelected(true);
-        //        } else {
-        //            _cb4xConsumer.setSelected(false);
-        //        }
     }
     
     private void populatePurgeDelay(String time) {
@@ -632,72 +618,6 @@ public class WindowsSyncSettingPanel extends BlankPanel {
         
         checkFields();
         checkEnablingState();
-        
-        //    /* If the user tries to define a 4.x Consumer, the legacy settings are needed.
-        //       That's why we see if the legacy settings entry exists or not.
-        //       If the legacy settings entry does not exist we display an error message telling
-        //       the user that he/she has to define the legacy settings first.  In this dialog we
-        //       describe the steps to follow */
-        //        if (source.equals(_cb4xConsumer) && _cb4xConsumer.isSelected()) {
-        //            boolean legacyEntryExists = false;
-        //            try {
-        //                LDAPConnection ldc = _model.getServerInfo().getLDAPConnection();
-        //                String[] attrs = {"dn"};
-        //                LDAPEntry entry = ldc.read(LegacyConsumerSettingPanel.REPSETTINGS_DN, attrs);
-        //                if (entry != null) {
-        //                    legacyEntryExists = true;
-        //                }
-        //            } catch (LDAPException lde) {
-        //            }
-        //            if (!legacyEntryExists) {
-        //                _cb4xConsumer.setSelected(false);
-        //                DSUtil.showErrorDialog( _model.getFrame(),
-        //                "enable-legacy-error",
-        //                (String[])null,
-        //                _section,
-        //                _resource);
-        //            }
-        //    /* If the user tries to define a master or a hub, we need to log the changes.
-        //       That's why we see if the change log entry exists or not.
-        //       If the change log entry does not exist we display an error message telling
-        //       the user that he/she has to define the Change Log first.  In this dialog we
-        //       describe the steps to follow */
-        //        } else if ((source.equals(_rbIsActiveDirectory) && _rbIsActiveDirectory.isSelected()) ||
-        //        (source.equals(_rbIsLegacyNT) && _rbIsLegacyNT.isSelected())) {
-        //            boolean logChangesExists = false;
-        //            try {
-        //                LDAPConnection ldc = _model.getServerInfo().getLDAPConnection();
-        //                String[] attrs = {"dn"};
-        //                LDAPEntry entry = ldc.read(SupplierSettingPanel.CHANGELOG_DN, attrs);
-        //                if (entry != null) {
-        //                    logChangesExists = true;
-        //                }
-        //            } catch (LDAPException lde) {
-        //            }
-        //            if (!logChangesExists) {
-        //                //                _rbIsSlave.setSelected(true);
-        //                DSUtil.showErrorDialog( _model.getFrame(),
-        //                "enable-changelog-error",
-        //                (String[])null,
-        //                _section,
-        //                _resource);
-        //                //            }  else if (!_rbIsHub.isSelected()) {
-        //        /* In the case the user wants to configure a master replica (no hub selected)
-        //           we check if the database is on read-only mode or not.  If it is read only we display
-        //           an error message */
-        //                //                if (isDatabaseReadOnly()) {
-        //                //                  //  _rbIsSlave.setSelected(true);
-        //                //                    DSUtil.showErrorDialog( _model.getFrame(),
-        //                //                    "enable-master-error",
-        //                //                    (String[])null,
-        //                //                    _section,
-        //                //                    _resource);
-        //            }
-        //
-        //
-        //
-        //        }
-        
     }
     
     /**
@@ -1031,9 +951,6 @@ public class WindowsSyncSettingPanel extends BlankPanel {
         attr = new LDAPAttribute(ReplicationTool.REPLICA_TYPE_ATTR, value);
         attrSet.add(attr);
         
-//        attr = new LDAPAttribute(ReplicationTool.  REPLICA_LEGACY_CONSUMER_ATTR, value);
-//        attrSet.add(attr);
-
         // ndsDS5flags
         /* If we are a slave we DON'T log changes */
         //        if (!_rbIsSlave.isSelected()) {
@@ -1147,22 +1064,6 @@ public class WindowsSyncSettingPanel extends BlankPanel {
             value));
         }
         
-        // nsds5ReplicaLegacyConsumer
-        //        modType = _saveDS5ReplicaLegacyConsumerExist?LDAPModification.REPLACE:LDAPModification.ADD;
-        //        if (_cb4xConsumer.isSelected() &&
-        //        !_save4xConsumer ) {
-        //            value = "on";
-        //            modSet.add(modType,
-        //            new LDAPAttribute(ReplicationTool.REPLICA_LEGACY_CONSUMER_ATTR,
-        //            value));
-        //        } else if (!_cb4xConsumer.isSelected() &&
-        //        _save4xConsumer) {
-        //            value = "off";
-        //            modSet.add(modType,
-        //            new LDAPAttribute(ReplicationTool.REPLICA_LEGACY_CONSUMER_ATTR,
-        //            value));
-        //        }
-        
         // ndsDS5flags
         /* If we are a slave we DON'T log changes */
         modType = _saveDS5FlagsExist?LDAPModification.REPLACE:LDAPModification.ADD;
@@ -1531,12 +1432,6 @@ setValidFlag();
 //            }
 //        }
 //        
-//        /* Check the 4x compatibility */
-//        //        boolean is4xCompatibleDirty = false;
-//        //        if (_cb4xConsumer.isSelected() != _save4xConsumer) {
-//        //            is4xCompatibleDirty = true;
-//        //        }
-//        
 //        /* Check the supplier DN field */
 //        boolean isBindDNListDirty = false;
 //        boolean isBindDNListValid = true;
@@ -1575,12 +1470,6 @@ setValidFlag();
 //            setChangeState(_lBindDNList, CHANGE_STATE_UNMODIFIED);
 //        }
 //        
-//        //        if (is4xCompatibleDirty) {
-//        //            setChangeState( _cb4xConsumer, CHANGE_STATE_MODIFIED );
-//        //        } else {
-//        //            setChangeState( _cb4xConsumer, CHANGE_STATE_UNMODIFIED);
-//        //        }
-//        
 //        if (!isPurgeDelayValid) {
 //            setChangeState(_lPurgeDelay, CHANGE_STATE_ERROR );
 //            setChangeState(_cbPurgeDelayNever, CHANGE_STATE_ERROR );
@@ -1606,7 +1495,6 @@ setValidFlag();
 //        }
 //        
 //        if (isReplicaIDDirty ||
-//        //        is4xCompatibleDirty ||
 //        isBindDNListDirty ||
 //        isPurgeDelayDirty ||
 //        isReferralListDirty ||
@@ -1713,7 +1601,6 @@ setValidFlag();
     
     private JCheckBox _cbWindowsReplicaEnabled = null;
     private JCheckBox _cbPurgeDelayNever = null;
-    private JCheckBox _cb4xConsumer = null;
     
     private JRadioButton _rbIsLegacyNT = null;
     private JRadioButton _rbIsActiveDirectory = null;
@@ -1762,7 +1649,6 @@ setValidFlag();
     private boolean _saveReadOnly = false;
     //private boolean _saveReplicaEnabled = false;
     //private boolean _saveDS5Flags = false;
-    //private boolean _save4xConsumer = false;
     private boolean _saveWindowsReplicaEnabled = false;
   /* These members, tell which are the values in the server (or the default values
      if there are no values on the server) */
