@@ -1414,21 +1414,11 @@ public class DSEntryPanel extends JPanel implements ActionListener,
 		
 		String stringRDN = "";
 		for (int i=0; i < attributes.length ; i++) {
-			/* We add the quotes if necessary*/		    
-			if (values[i].indexOf(',') >= 0) {
-				String unquotedValue = MappingUtils.unQuote(values[i]);
-				if (i>0) {					
-					stringRDN = stringRDN + " + " + attributes[i]+"=\""+unquotedValue+"\"";
-				}  else {
-					stringRDN = attributes[i]+"=\""+unquotedValue+"\"";
-				}
-			} else {
-				if (i>0) {
-					stringRDN = stringRDN + " + " +attributes[i]+"="+values[i];
-				} else {
-					stringRDN = attributes[i]+"="+values[i];
-				}
-			}
+		    if (i>0) {
+			stringRDN = stringRDN + " + " +attributes[i]+"="+DSUtil.escapeDNVal(values[i]);
+		    } else {
+			stringRDN = attributes[i]+"="+DSUtil.escapeDNVal(values[i]);
+		    }
 		}
 		Debug.println("DSEntryPanel.updateDNValue: rdn = "+stringRDN);				
 				  
@@ -1442,7 +1432,7 @@ public class DSEntryPanel extends JPanel implements ActionListener,
 			parentDN = new DN(stringRDN);
 		}
 		_dn = parentDN;
-		String dn = stringRDN+", "+_dn.getParent();
+		String dn = stringRDN+","+_dn.getParent();
 		Debug.println("DSEntryPanel.updateDNValue: dn = "+dn);
 		if (dn != null) {
 			_dnLabel.setText("dn: "+dn);
@@ -1498,11 +1488,22 @@ public class DSEntryPanel extends JPanel implements ActionListener,
                                                String currentValue = (String)en.nextElement();
                                                /* Just in case we have quotes... */                                               
                                                if (value.equals(currentValue) ||
-                                                   MappingUtils.unescapeBackslash(value).equals(currentValue) ||
-                                                   value.equals('"'+currentValue+'"')) {
+                                                   DSUtil.escapeDNVal(value).equals(currentValue)) {
                                                        typeWithValue = true;
                                                        break;
                                                }
+                                               // note: current versions of the directory server
+                                               // use dn values as values of RDNs e.g.
+                                               // cn=dc\3Dexample\2Cdc\3Dcom,cn=mapping tree, cn=config
+                                               // where dc\3Dexample\2Cdc\3Dcom is dc=example,dc=com
+                                               String unescval = DSUtil.unEscapeRDNVal(value);
+                                               if (DSUtil.isValidDN(unescval)) {
+                                            	   // compare as DNs
+                                            	   if (DSUtil.equalDNs(unescval, currentValue)) {
+                                            		   typeWithValue = true;
+                                            		   break;
+                                            	   }
+                                               }
                                        }
                                        if (typeWithValue) {
                                                continue;
